# RawUnit


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **int** |  | [readonly] 
**type** | **str** |  | 
**name** | **str, none_type** |  | [optional] 
**unit_type** | **str, none_type** |  | [optional] 
**prefix** | **str, none_type** |  | [optional] 
**elements** | **{str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type** |  | [optional] 
**conversion_factor** | **float, none_type** |  | [optional] 
**dimensions** | **[float], none_type** |  | [optional] 
**conversion_baseunit_index** | **int, none_type** |  | [optional] 
**is_default** | **bool, none_type** |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


